| Title: | Datasets from the Survival TV Series Alone |
|---|---|
| Description: | A collection of datasets on the Alone survival TV series in tidy format. Included in the package are 4 datasets detailing the survivors, their loadouts, episode details and season information. |
| Authors: | Daniel Oehm [aut, cre], Carly Levitz [ctb] |
| Maintainer: | Daniel Oehm <[email protected]> |
| License: | CC0 |
| Version: | 0.6 |
| Built: | 2026-05-22 18:53:43 UTC |
| Source: | https://github.com/doehm/alone |
Contains details of each episode including the title, number of viewers, beginning quote and IMDb rating
episodesepisodes
This data frame contains the following columns:
versionCountry code for the version of the show
seasonThe season number
episode_number_overallEpisode number across seasons
episodeEpisode number
titleEpisode title
day_startThe day the episode started on
n_remainingHow are remaining at the start of the episode
air_dateDate the episode originally aired
viewersNumber of viewers in the US (millions)
quoteThe beginning quote
authorAuthor of the beginning quote
imdb_ratingIMDb rating of the episode
n_ratingsNumber of ratings given for the episode
descriptionDescription of the episode from IMDb
https://en.wikipedia.org/wiki/List_of_Alone_episodes#Season_1_(2015)_-_Vancouver_Island
library(dplyr) library(ggplot2) episodes |> ggplot(aes(episode_number_overall, viewers, colour = as.factor(season))) + geom_line()library(dplyr) library(ggplot2) episodes |> ggplot(aes(episode_number_overall, viewers, colour = as.factor(season))) + geom_line()
Information on each survivalists loadout of 10 items
loadoutsloadouts
This data frame contains the following columns:
versionCountry code for the version of the show
seasonThe season number
idSurvivalist ID
nameName of the survivalist
item_numberItem number
item_detailedDetailed loadout item description
itemLoadout item. Simplified for aggregation
https://en.wikipedia.org/wiki/Alone_(TV_series)
library(dplyr) library(ggplot2) library(forcats) loadouts |> count(item) |> mutate(item = fct_reorder(item, n, max)) |> ggplot(aes(item, n)) + geom_col() + geom_text(aes(item, n + 3, label = n)) + coord_flip()library(dplyr) library(ggplot2) library(forcats) loadouts |> count(item) |> mutate(item = fct_reorder(item, n, max)) |> ggplot(aes(item, n)) + geom_col() + geom_text(aes(item, n + 3, label = n)) + coord_flip()
Season summary includes location and other season level information
seasonsseasons
This data frame contains the following columns:
versionCountry code for the version of the show
seasonThe season number
subtitleSeason subtitle
locationLocation
countryCountry
regionRegion
n_survivorsNumber of survivors. Season 4 there were 7 teams of 2.
latLatitude
lonLongitude
date_drop_offDate the survivors where dropped off
https://en.wikipedia.org/wiki/Alone_(TV_series)
library(dplyr) seasons |> count(country)library(dplyr) seasons |> count(country)
Contains details of each survivalist including demographics and results.
survivalistssurvivalists
This data frame contains the following columns:
versionCountry code for the version of the show
seasonThe season number
idSurvivalist ID
nameName of the survivalist
first_nameFirst name of the survivalist
last_nameLast name of the survivalist
ageAge of survivalist
genderGender
cityCity
stateState
countryCountry
resultPlace the survivalist finished in the season
days_lastedThe number of days lasted in the game before tapping out or winning
medically_evacuatedLogical. If the survivalist was medically evacuated from the game
reason_tapped_outThe reason the survivalist tapped out of the game. NA means
they were the winner
reason_categoryA simplified category of the reason for tapping out
episode_tappedEpisode tapped out
teamThe team they were associated with (only for season 4)
day_linked_upDay the team members linked up
professionProfession
https://en.wikipedia.org/wiki/List_of_Alone_episodes#Season_1_(2015)_-_Vancouver_Island
library(dplyr) library(ggplot2) survivalists |> count(reason_category, gender) |> filter(!is.na(reason_category)) |> ggplot(aes(reason_category, n, fill = gender)) + geom_col()library(dplyr) library(ggplot2) survivalists |> count(reason_category, gender) |> filter(!is.na(reason_category)) |> ggplot(aes(reason_category, n, fill = gender)) + geom_col()